@@ -656,7 +656,7 @@ class log_monitor_manager {
         }
         
         // Check if IP is already blocked for this service to prevent infinite loops
-        $stmt = $this->db->prepare('SELECT * FROM service_blocked_ips WHERE service_type = ? AND ip_address = ? AND (unblock_time > ? OR unblock_time = 0)');
+        $stmt = $this->db->prepare('SELECT * FROM service_blocked_ips WHERE service_type = ? AND ip_address = ? AND (unblock_time > ? OR unblock_time = -1)');
         $stmt->bindValue(1, $service, SQLITE3_TEXT);
         $stmt->bindValue(2, $ip, SQLITE3_TEXT);
         $stmt->bindValue(3, time(), SQLITE3_INTEGER);
@@ -688,8 +688,8 @@ class log_monitor_manager {
             $firewall_rule_added = $this->add_service_blocks($ip) ? 1 : 0;
         }
         
-        // Calculate unblock time - 0 means permanent block
-        $unblock_time = $permanent ? 0 : (time() + $block_duration);
+        // Calculate unblock time - -1 means permanent block
+        $unblock_time = $permanent ? -1 : (time() + $block_duration);
         
         $stmt = $this->db->prepare('INSERT OR REPLACE INTO service_blocked_ips (service_type, ip_address, block_time, unblock_time, reason, failed_attempts, firewall_rule_added) VALUES (?, ?, ?, ?, ?, ?, ?)');
         $stmt->bindValue(1, $service, SQLITE3_TEXT);
@@ -719,7 +719,7 @@ class log_monitor_manager {
         }
         
         // Get all services this IP is blocked from
-        $stmt = $this->db->prepare('SELECT DISTINCT service_type FROM service_blocked_ips WHERE ip_address = ? AND (unblock_time > ? OR unblock_time = 0)');
+        $stmt = $this->db->prepare('SELECT DISTINCT service_type FROM service_blocked_ips WHERE ip_address = ? AND (unblock_time > ? OR unblock_time = -1)');
         $stmt->bindValue(1, $ip, SQLITE3_TEXT);
         $stmt->bindValue(2, time(), SQLITE3_INTEGER);
         $result = $stmt->execute();
@@ -909,7 +909,7 @@ class log_monitor_manager {
     }
     
     public function is_service_ip_blocked($service, $ip) {
-        $stmt = $this->db->prepare('SELECT * FROM service_blocked_ips WHERE service_type = ? AND ip_address = ? AND (unblock_time > ? OR unblock_time = 0)');
+        $stmt = $this->db->prepare('SELECT * FROM service_blocked_ips WHERE service_type = ? AND ip_address = ? AND (unblock_time > ? OR unblock_time = -1)');
         $stmt->bindValue(1, $service, SQLITE3_TEXT);
         $stmt->bindValue(2, $ip, SQLITE3_TEXT);
         $stmt->bindValue(3, time(), SQLITE3_INTEGER);
@@ -1170,11 +1170,11 @@ class log_monitor_manager {
     
     public function get_service_blocked_ips($service = null) {
         if ($service) {
-            $stmt = $this->db->prepare('SELECT * FROM service_blocked_ips WHERE service_type = ? AND (unblock_time > ? OR unblock_time = 0) ORDER BY block_time DESC');
+            $stmt = $this->db->prepare('SELECT * FROM service_blocked_ips WHERE service_type = ? AND (unblock_time > ? OR unblock_time = -1) ORDER BY block_time DESC');
             $stmt->bindValue(1, $service, SQLITE3_TEXT);
             $stmt->bindValue(2, time(), SQLITE3_INTEGER);
         } else {
-            $stmt = $this->db->prepare('SELECT * FROM service_blocked_ips WHERE unblock_time > ? OR unblock_time = 0 ORDER BY block_time DESC');
+            $stmt = $this->db->prepare('SELECT * FROM service_blocked_ips WHERE unblock_time > ? OR unblock_time = -1 ORDER BY block_time DESC');
             $stmt->bindValue(1, time(), SQLITE3_INTEGER);
         }
         
@@ -1193,7 +1193,7 @@ class log_monitor_manager {
      * @return array Array of unique blocked IPs with original blocking service
      */
     public function get_unique_blocked_ips() {
-        $stmt = $this->db->prepare('SELECT * FROM service_blocked_ips WHERE unblock_time > ? OR unblock_time = 0 ORDER BY ip_address, block_time ASC');
+        $stmt = $this->db->prepare('SELECT * FROM service_blocked_ips WHERE unblock_time > ? OR unblock_time = -1 ORDER BY ip_address, block_time ASC');
         $stmt->bindValue(1, time(), SQLITE3_INTEGER);
         
         $result = $stmt->execute();
@@ -1236,7 +1236,7 @@ class log_monitor_manager {
         
         try {
             // Get all currently blocked IPs from service database
-            $stmt = $this->db->prepare('SELECT DISTINCT ip_address, reason FROM service_blocked_ips WHERE unblock_time > ? OR unblock_time = 0');
+            $stmt = $this->db->prepare('SELECT DISTINCT ip_address, reason FROM service_blocked_ips WHERE unblock_time > ? OR unblock_time = -1');
             $stmt->bindValue(1, time(), SQLITE3_INTEGER);
             $result = $stmt->execute();
             
@@ -1366,7 +1366,7 @@ class log_monitor_manager {
             );
             
             // Get blocked IPs count
-            $stmt = $this->db->prepare('SELECT COUNT(*) as count FROM service_blocked_ips WHERE service_type = ? AND (unblock_time > ? OR unblock_time = 0)');
+            $stmt = $this->db->prepare('SELECT COUNT(*) as count FROM service_blocked_ips WHERE service_type = ? AND (unblock_time > ? OR unblock_time = -1)');
             $stmt->bindValue(1, $service, SQLITE3_TEXT);
             $stmt->bindValue(2, time(), SQLITE3_INTEGER);
             $result = $stmt->execute();
